import * as bingo from 'bingo';
import * as bingo_stratum from 'bingo-stratum';
import * as bingo_stratum_lib_types_templates_js from 'bingo-stratum/lib/types/templates.js';
import * as zod from 'zod';
export { template } from './template.js';
export { BaseOptions, base } from './base.js';
export { blocks } from './blocks/index.js';
export { presets } from './presets/index.js';
export { blockAllContributors } from './blocks/blockAllContributors.js';
export { blockAreTheTypesWrong } from './blocks/blockAreTheTypesWrong.js';
export { blockCodecov } from './blocks/blockCodecov.js';
export { blockContributingDocs } from './blocks/blockContributingDocs.js';
export { blockContributorCovenant } from './blocks/blockContributorCovenant.js';
export { blockCSpell } from './blocks/blockCSpell.js';
export { blockCTATransitions } from './blocks/blockCTATransitions.js';
export { blockDevelopmentDocs } from './blocks/blockDevelopmentDocs.js';
export { blockESLint } from './blocks/blockESLint.js';
export { blockESLintComments } from './blocks/blockESLintComments.js';
export { blockESLintJSDoc } from './blocks/blockESLintJSDoc.js';
export { blockESLintJSONC } from './blocks/blockESLintJSONC.js';
export { blockESLintMarkdown } from './blocks/blockESLintMarkdown.js';
export { blockESLintMoreStyling } from './blocks/blockESLintMoreStyling.js';
export { blockESLintNode } from './blocks/blockESLintNode.js';
export { blockESLintPackageJson } from './blocks/blockESLintPackageJson.js';
export { blockESLintPerfectionist } from './blocks/blockESLintPerfectionist.js';
export { blockESLintPlugin } from './blocks/blockESLintPlugin.js';
export { blockESLintRegexp } from './blocks/blockESLintRegexp.js';
export { blockESLintYML } from './blocks/blockESLintYML.js';
export { blockFunding } from './blocks/blockFunding.js';
export { blockGitHubActionsCI } from './blocks/blockGitHubActionsCI.js';
export { blockGitHubIssueTemplates } from './blocks/blockGitHubIssueTemplates.js';
export { blockGitHubPRTemplate } from './blocks/blockGitHubPRTemplate.js';
export { blockGitignore } from './blocks/blockGitignore.js';
export { blockKnip } from './blocks/blockKnip.js';
export { blockMain } from './blocks/blockMain.js';
export { blockMarkdownlint } from './blocks/blockMarkdownlint.js';
export { blockMITLicense } from './blocks/blockMITLicense.js';
export { blockNcc } from './blocks/blockNcc.js';
export { blockNvmrc } from './blocks/blockNvmrc.js';
export { blockPackageJson } from './blocks/blockPackageJson.js';
export { blockPnpmDedupe } from './blocks/blockPnpmDedupe.js';
export { blockPRCompliance } from './blocks/blockPRCompliance.js';
export { blockPrettier } from './blocks/blockPrettier.js';
export { blockPrettierPluginCurly } from './blocks/blockPrettierPluginCurly.js';
export { blockPrettierPluginPackageJson } from './blocks/blockPrettierPluginPackageJson.js';
export { blockPrettierPluginSh } from './blocks/blockPrettierPluginSh.js';
export { blockREADME } from './blocks/blockREADME.js';
export { blockReleaseIt } from './blocks/blockReleaseIt.js';
export { blockRenovate } from './blocks/blockRenovate.js';
export { blockSecurityDocs } from './blocks/blockSecurityDocs.js';
export { blockTemplatedWith } from './blocks/blockTemplatedWith.js';
export { blockTSup } from './blocks/blockTSup.js';
export { blockTypeScript } from './blocks/blockTypeScript.js';
export { blockVitest } from './blocks/blockVitest.js';
export { blockVSCode } from './blocks/blockVSCode.js';
export { presetCommon } from './presets/common.js';
export { presetEverything } from './presets/everything.js';
export { presetMinimal } from './presets/minimal.js';

declare const createConfig: bingo.CreateTemplateConfig<{
    access: zod.ZodUnion<[zod.ZodLiteral<"public">, zod.ZodLiteral<"restricted">]>;
    author: zod.ZodOptional<zod.ZodString>;
    bin: zod.ZodOptional<zod.ZodUnion<[zod.ZodString, zod.ZodRecord<zod.ZodString, zod.ZodString>]>>;
    contributors: zod.ZodOptional<zod.ZodArray<zod.ZodObject<{
        avatar_url: zod.ZodString;
        contributions: zod.ZodArray<zod.ZodString, "many">;
        login: zod.ZodString;
        name: zod.ZodString;
        profile: zod.ZodString;
    }, "strip", zod.ZodTypeAny, {
        avatar_url: string;
        contributions: string[];
        login: string;
        name: string;
        profile: string;
    }, {
        avatar_url: string;
        contributions: string[];
        login: string;
        name: string;
        profile: string;
    }>, "many">>;
    description: zod.ZodDefault<zod.ZodString>;
    directory: zod.ZodString;
    documentation: zod.ZodObject<{
        development: zod.ZodOptional<zod.ZodString>;
        readme: zod.ZodObject<{
            additional: zod.ZodOptional<zod.ZodString>;
            explainer: zod.ZodOptional<zod.ZodString>;
            footnotes: zod.ZodOptional<zod.ZodString>;
            usage: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            usage: string;
            additional?: string | undefined;
            explainer?: string | undefined;
            footnotes?: string | undefined;
        }, {
            usage: string;
            additional?: string | undefined;
            explainer?: string | undefined;
            footnotes?: string | undefined;
        }>;
    }, "strip", zod.ZodTypeAny, {
        readme: {
            usage: string;
            additional?: string | undefined;
            explainer?: string | undefined;
            footnotes?: string | undefined;
        };
        development?: string | undefined;
    }, {
        readme: {
            usage: string;
            additional?: string | undefined;
            explainer?: string | undefined;
            footnotes?: string | undefined;
        };
        development?: string | undefined;
    }>;
    email: zod.ZodEffects<zod.ZodUnion<[zod.ZodString, zod.ZodObject<{
        github: zod.ZodString;
        npm: zod.ZodString;
    }, "strip", zod.ZodTypeAny, {
        github: string;
        npm: string;
    }, {
        github: string;
        npm: string;
    }>]>, {
        github: string;
        npm: string;
    }, string | {
        github: string;
        npm: string;
    }>;
    emoji: zod.ZodOptional<zod.ZodString>;
    existingLabels: zod.ZodOptional<zod.ZodArray<zod.ZodObject<{
        color: zod.ZodString;
        description: zod.ZodString;
        name: zod.ZodString;
    }, "strip", zod.ZodTypeAny, {
        name: string;
        description: string;
        color: string;
    }, {
        name: string;
        description: string;
        color: string;
    }>, "many">>;
    funding: zod.ZodOptional<zod.ZodString>;
    guide: zod.ZodOptional<zod.ZodObject<{
        href: zod.ZodString;
        title: zod.ZodString;
    }, "strip", zod.ZodTypeAny, {
        href: string;
        title: string;
    }, {
        href: string;
        title: string;
    }>>;
    keywords: zod.ZodOptional<zod.ZodArray<zod.ZodString, "many">>;
    logo: zod.ZodOptional<zod.ZodObject<{
        alt: zod.ZodString;
        height: zod.ZodOptional<zod.ZodNumber>;
        src: zod.ZodString;
        width: zod.ZodOptional<zod.ZodNumber>;
    }, "strip", zod.ZodTypeAny, {
        alt: string;
        src: string;
        height?: number | undefined;
        width?: number | undefined;
    }, {
        alt: string;
        src: string;
        height?: number | undefined;
        width?: number | undefined;
    }>>;
    node: zod.ZodObject<{
        minimum: zod.ZodString;
        pinned: zod.ZodOptional<zod.ZodString>;
    }, "strip", zod.ZodTypeAny, {
        minimum: string;
        pinned?: string | undefined;
    }, {
        minimum: string;
        pinned?: string | undefined;
    }>;
    owner: zod.ZodString;
    packageData: zod.ZodOptional<zod.ZodObject<{
        dependencies: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodString>>;
        devDependencies: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodString>>;
        peerDependencies: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodString>>;
        peerDependenciesMeta: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodUnknown>>;
        scripts: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodString>>;
    }, "strip", zod.ZodTypeAny, {
        dependencies?: Record<string, string> | undefined;
        devDependencies?: Record<string, string> | undefined;
        peerDependencies?: Record<string, string> | undefined;
        peerDependenciesMeta?: Record<string, unknown> | undefined;
        scripts?: Record<string, string> | undefined;
    }, {
        dependencies?: Record<string, string> | undefined;
        devDependencies?: Record<string, string> | undefined;
        peerDependencies?: Record<string, string> | undefined;
        peerDependenciesMeta?: Record<string, unknown> | undefined;
        scripts?: Record<string, string> | undefined;
    }>>;
    pnpm: zod.ZodOptional<zod.ZodString>;
    repository: zod.ZodString;
    rulesetId: zod.ZodOptional<zod.ZodString>;
    title: zod.ZodString;
    type: zod.ZodOptional<zod.ZodUnion<[zod.ZodLiteral<"commonjs">, zod.ZodLiteral<"module">]>>;
    version: zod.ZodOptional<zod.ZodString>;
    words: zod.ZodOptional<zod.ZodArray<zod.ZodString, "many">>;
    workflowsVersions: zod.ZodOptional<zod.ZodRecord<zod.ZodString, zod.ZodRecord<zod.ZodString, zod.ZodObject<{
        hash: zod.ZodOptional<zod.ZodString>;
        pinned: zod.ZodOptional<zod.ZodBoolean>;
    }, "strip", zod.ZodTypeAny, {
        pinned?: boolean | undefined;
        hash?: string | undefined;
    }, {
        pinned?: boolean | undefined;
        hash?: string | undefined;
    }>>>>;
} & bingo_stratum_lib_types_templates_js.StratumTemplateOptionsShape, bingo_stratum.StratumRefinements<{
    access: "public" | "restricted";
    description: string;
    directory: string;
    documentation: {
        readme: {
            usage: string;
            additional?: string | undefined;
            explainer?: string | undefined;
            footnotes?: string | undefined;
        };
        development?: string | undefined;
    };
    email: {
        github: string;
        npm: string;
    };
    title: string;
    node: {
        minimum: string;
        pinned?: string | undefined;
    };
    owner: string;
    repository: string;
    type?: "commonjs" | "module" | undefined;
    author?: string | undefined;
    bin?: string | Record<string, string> | undefined;
    contributors?: {
        avatar_url: string;
        contributions: string[];
        login: string;
        name: string;
        profile: string;
    }[] | undefined;
    emoji?: string | undefined;
    existingLabels?: {
        name: string;
        description: string;
        color: string;
    }[] | undefined;
    funding?: string | undefined;
    guide?: {
        href: string;
        title: string;
    } | undefined;
    keywords?: string[] | undefined;
    logo?: {
        alt: string;
        src: string;
        height?: number | undefined;
        width?: number | undefined;
    } | undefined;
    packageData?: {
        dependencies?: Record<string, string> | undefined;
        devDependencies?: Record<string, string> | undefined;
        peerDependencies?: Record<string, string> | undefined;
        peerDependenciesMeta?: Record<string, unknown> | undefined;
        scripts?: Record<string, string> | undefined;
    } | undefined;
    pnpm?: string | undefined;
    rulesetId?: string | undefined;
    version?: string | undefined;
    words?: string[] | undefined;
    workflowsVersions?: Record<string, Record<string, {
        pinned?: boolean | undefined;
        hash?: string | undefined;
    }>> | undefined;
}>>;

export { createConfig };
